from django.contrib import admin

from .models import ContactRequest


@admin.register(ContactRequest)
class ContactRequestAdmin(admin.ModelAdmin):
    date_hierarchy = 'created'

    list_display = [
        'name',
        'created',
        'contacted',
    ]

    list_filter = [
        'contacted',
    ]

    readonly_fields = [
        'name',
        'email',
        'phone_number',
        'message',
    ]



from django.db import models
from django.utils.translation import gettext as _


class ContactRequest(models.Model):
    """
    This model will manage the requests from the contact form
    """

    created = models.DateTimeField(_('created'), auto_now_add=True)
    modified = models.DateTimeField(_('modified'), auto_now=True)
    name = models.CharField(_('name'), max_length=255)
    email = models.EmailField(_('email'))
    phone_number = models.CharField(_('phone number'), max_length=255)
    message = models.TextField(_('message'))
    contacted = models.BooleanField(_('contacted'), default=False)

    class Meta:
        verbose_name = _("Contact request")
        verbose_name_plural = _("Contact requests")

    def __str__(self):
        return self.name

    @property
    def contact_information(self):
        if self.email and self.phone_number:
            return _("{email} or {phone_number}").format(
                email=self.email,
                phone_number=self.phone_number
            )
        if self.email:
            return self.email
        return self.phone_number



# Generated by Django 2.2.1 on 2019-05-03 17:44

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ContactRequest',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='creado')),
                ('modified', models.DateTimeField(auto_now=True, verbose_name='modificado')),
                ('name', models.CharField(max_length=255, verbose_name='nombre')),
                ('email', models.EmailField(max_length=254, verbose_name='email')),
                ('phone_number', models.CharField(max_length=255, verbose_name='phone number')),
                ('message', models.TextField(verbose_name='message')),
                ('contacted', models.BooleanField(default=False, verbose_name='contacted')),
            ],
            options={
                'verbose_name': 'Contact request',
                'verbose_name_plural': 'Contact requests',
            },
        ),
    ]



from django import forms
from django.utils.translation import gettext as _

from captcha.fields import ReCaptchaField

from .models import ContactRequest


class ContactRequestForm(forms.ModelForm):
    captcha = ReCaptchaField(label='')

    class Meta:
        model = ContactRequest
        fields = [
            'name',
            'email',
            'phone_number',
            'message'
        ]

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['email'].required = False
        self.fields['phone_number'].required = False

    def clean(self):
        cleaned_data = super().clean()

        if not cleaned_data.get('email') and not cleaned_data.get('phone_number'):
            raise forms.ValidationError(_("Email or phone number are required."))

        return cleaned_data



from django.conf import settings
from django.core.mail import send_mail
from django.template.loader import render_to_string
from django.utils.translation import gettext as _

from .models import ContactRequest


def _send_mail(contact_request):
    """
    Given a contact request instance sends an email to the web admin with the
    notification about its creation.
    Retruns the amount of sent emails.
    """

    site_domain = settings.DJTOOLS_CONTACTREQUESTS_SITE_DOMAIN
    message = render_to_string(
        'djtools/contactrequests/contactrequest_email.txt',
        {
            'object': contact_request,
            'DJTOOLS_CONTACTREQUESTS_SITE_DOMAIN': site_domain
        }
    )

    return send_mail(
        subject=_(f"You have a contact request from {site_domain}"),
        message=message,
        from_email=settings.DJTOOLS_CONTACTREQUESTS_MAIL_FROM,
        recipient_list=settings.DJTOOLS_CONTACTREQUESTS_MAIL_TO,
        fail_silently=False,
    )


def create_contact_request(name, email, phone_number, message, captcha=None):
    """
    Creates a new instance of ContactRequest and sends a notification email.
    captcha argument can be ignored
    """

    contact_request = ContactRequest.objects.create(
        name=name,
        email=email,
        phone_number=phone_number,
        message=message
    )
    amount_sent_emails = _send_mail(contact_request)
    return contact_request, amount_sent_emails



from django.apps import AppConfig
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured
from django.utils.translation import gettext as _


class ContactRequestsConfig(AppConfig):
    name = 'djtools.contactrequests'
    label = 'djtools.contactrequests'
    verbose_name = _("Contact form")

    def ready(self):
        if not hasattr(settings, 'DJTOOLS_CONTACTREQUESTS_SITE_DOMAIN'):
            raise ImproperlyConfigured(
                "The DJTOOLS_CONTACTREQUESTS_SITE_DOMAIN setting must not be empty."
            )
        if not hasattr(settings, 'DJTOOLS_CONTACTREQUESTS_MAIL_FROM'):
            raise ImproperlyConfigured(
                "The DJTOOLS_CONTACTREQUESTS_MAIL_FROM setting must not be empty."
            )
        if not hasattr(settings, 'DJTOOLS_CONTACTREQUESTS_MAIL_TO'):
            raise ImproperlyConfigured(
                "The DJTOOLS_CONTACTREQUESTS_MAIL_TO setting must not be empty."
            )



import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-tools-contact-requests',
    version='1.0.0',
    packages=find_packages(exclude=("tests",)),
    include_package_data=True,
    description='Simple Django app to manage contact requests',
    long_description=README,
    long_description_content_type="text/markdown",
    author='Toni Colom',
    author_email='toni@semicolom.com',
    url='https://github.com/semicolom/django-tools-contact-requests',
    install_requires=[
        'django-recaptcha',
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 2.0',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)



from django.contrib import messages
from django.urls import reverse_lazy
from django.utils.translation import gettext as _
from django.views.generic.edit import FormView

from . import forms, services


class ContactRequestView(FormView):
    form_class = forms.ContactRequestForm
    template_name = 'djtools/contactrequests/contactrequest_form.html'
    success_url = reverse_lazy('contact')

    def form_valid(self, form):
        """
        Displays a success message when the form is submitted correctly
        """

        services.create_contact_request(**form.cleaned_data)
        messages.success(self.request, _("Your request has been submitted."))
        return super().form_valid(form)

    def form_invalid(self, form):
        """
        Displays an error message when the form is submitted with errors
        """

        messages.error(self.request, _("Please, check the form errors."))
        return super().form_invalid(form)
